@@ -3,4 +3,6 @@ from .read_vis import *
 from .write_vis import *
 from .describe_vis import *
 from .read_image import *
-from .write_image import *
\ No newline at end of file
+from .write_image import *
+from .write_zarr import *
+from .append_zarr import *
