@@ -2,10 +2,13 @@
 from .applyflags import *
 from .chanaverage import *
 from .chansmooth import *
-from .joinspw import *
-from .recalculateuvw import *
-from .regridspw import *
+from .ddijoin import *
+from .visjoin import *
+from .phaseshift import *
+from .ddiregrid import *
 from .timeaverage import *
 from .uvcontfit import *
 from .uvmodelfit import *
 from .visplot import *
+from .sdfit import *
+from .sdpolaverage import *
